@@ -1,5 +1,3 @@
-import os
-
 from sqlobject import col, dberrors
 from sqlobject.compat import PY2
 from sqlobject.dbconnection import DBAPI
@@ -229,7 +227,7 @@ class MySQLConnection(DBAPI):
             self.printDebug(conn, query, 'QueryR')
         dbEncoding = self.dbEncoding
         if dbEncoding and not isinstance(query, bytes) and (
-                self.driver in ('connector', 'oursql')):
+                self.driver in ('mysqldb', 'connector', 'oursql')):
             query = query.encode(dbEncoding, 'surrogateescape')
         # When a server connection is lost and a query is attempted, most of
         # the time the query will raise a SERVER_LOST exception, then at the
@@ -482,9 +480,6 @@ class MySQLConnection(DBAPI):
     def can_use_microseconds(self):
         if self._can_use_microseconds is not None:
             return self._can_use_microseconds
-        if os.environ.get('APPVEYOR') or os.environ.get('TRAVIS'):
-            self._can_use_microseconds = False
-            return False
         server_version = self.server_version()
         if server_version is None:
             return None
